@@ -1,6 +1,6 @@
 /*******************************************************************************
  * @license
- * Copyright (c) 2011, 2016 IBM Corporation and others.
+ * Copyright (c) 2011, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials are made 
  * available under the terms of the Eclipse Public License v1.0 
  * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
@@ -21,8 +21,9 @@ define("orion/editor/contentAssist", [ //$NON-NLS-0$
 	'orion/editor/util', //$NON-NLS-0$
 	'orion/util', //$NON-NLS-0$
 	'orion/webui/littlelib', //$NON-NLS-0$
-	'orion/metrics' //$NON-NLS-0$
-], function(messages, mKeyBinding, mKeyModes, mEventTarget, Deferred, objects, mTooltip, textUtil, util, lib, mMetrics) {
+	'orion/metrics', //$NON-NLS-0$
+	'orion/lsp/utils'
+], function(messages, mKeyBinding, mKeyModes, mEventTarget, Deferred, objects, mTooltip, textUtil, util, lib, mMetrics, Utils) {
 	/**
 	 * @name orion.editor.ContentAssistProvider
 	 * @class Interface defining a provider of content assist proposals.
@@ -277,7 +278,7 @@ define("orion/editor/contentAssist", [ //$NON-NLS-0$
 			// the beginning of the selection and the current caret offset
 			var offset = this.textView.getCaretOffset();
 			var sel = this.textView.getSelection();
-			var selectionStart = Math.min(sel.start, sel.end);			
+			var selectionStart = Math.min(sel.start, sel.end);
 			this._initialCaretOffset = Math.min(offset, selectionStart);
 			this._computedProposals = null;
 			delete this._autoApply;
@@ -407,7 +408,13 @@ define("orion/editor/contentAssist", [ //$NON-NLS-0$
 					indentation: indentation
 				};
 				try {
-					if ((func = provider.computeContentAssist)) {
+					if (providerInfo.lspServer) {
+						// completion comes from the lsp service
+						ecProvider = _self.editorContextProvider;
+						editorContext = ecProvider.getEditorContext();
+						params = objects.mixin(params, ecProvider.getOptions());
+						promise = Utils.computeContentAssist(provider, editorContext, params);
+					} else if ((func = provider.computeContentAssist)) {
 						ecProvider = _self.editorContextProvider;
 						editorContext = ecProvider.getEditorContext();
 						params = objects.mixin(params, ecProvider.getOptions());
@@ -637,7 +644,7 @@ define("orion/editor/contentAssist", [ //$NON-NLS-0$
 			
 			this._providers = providerInfoArray;
 			this._charTriggersInstalled = providerInfoArray.some(function(info){
-				return info.charTriggers;
+				return info.charTriggers || info.lspServer;
 			});
 			this._updateAutoTriggerListenerState();
 		},
@@ -731,7 +738,24 @@ define("orion/editor/contentAssist", [ //$NON-NLS-0$
 					// check if the charTriggers RegExp matches the currentChar
 					// we're assuming that this will fail much more often than
 					// the excludedStyles test so do this first for better performance
-					var charTriggers = info.charTriggers;
+					var charTriggers = null;
+					if (info.lspServer) {
+						var capabilities = info.provider.capabilities;
+						if (capabilities && capabilities.completionProvider) {
+							// we should get the completion options
+							var completionOptions = capabilities.completionProvider;
+
+							// build up the regex for triggerCharacters
+							var triggers = "[";
+							completionOptions.triggerCharacters.forEach(function(character) {
+							triggers += character;
+							});
+							triggers += "]";
+							info.charTriggers = new RegExp(triggers);
+						}
+						delete info.lspServer;
+					} 
+					charTriggers= info.charTriggers;
 					if (charTriggers && charTriggers.test(currentChar)) {
 						var isExcluded = false;
 						var excludedStyles = info.excludedStyles;
